.. module:: ase.gui
   :synopsis: Simple graphical user-interface for ASE.


.. index:: gui, ag, ase-gui

.. _ase-gui:

=======
ase-gui
=======

The graphical user-interface allows users to visualize, manipulate,
and render molecular systems and atoms objects. It also allows to
setup and run a number of calculations and can be used to transfer
between different file formats.

.. image:: ag.png
   :height: 200 pt

.. toctree::

   basics
   edit
   view
   tools
   setup
   calculate

